pub struct HeapDealloc { /* private fields */ }Expand description
Frees memory via alloc::alloc::dealloc with the stored Layout.
This is the default dealloc strategy for arenas that allocate their own backing memory.
Implementations
Sourceimpl HeapDealloc
impl HeapDealloc
Sourcepub fn new(layout: Layout) -> Self
pub fn new(layout: Layout) -> Self
Wrap a Layout for deallocation via alloc::alloc::dealloc.
The layout must match the one used to allocate the memory.